==> cartoun-detailactivite-1.0.0-sources.jar: fr/toutatice/cartoun/portlet/detailactivite/bean/ActiviteBean.java <==
package fr.toutatice.cartoun.portlet.detailactivite.bean;

import java.util.Date;
import java.util.List;
import java.util.Map;

public class ActiviteBean {

	private List<ReferentBean> lstReferent1;
	private List<ReferentBean> lstReferent2;
	private List<ReferentBean> lstReferent3;
	private List<LinkBean> lstESoftware;
	private List<String> lstDisciplines;
	private List<String> lstPublics;
	private List<String> lstPedagogicals;
	private List<String> lstPractices;
	private List<String> lstCadres;
	private List<String> lstPlaces;
	private List<String> lstTools;
	private List<String> lstSoftware;
	private List<String> lstCompetence;
	private List<String> lstParcours;
	private List<String> lstAxes;
	private String summary;
	private String scenario;
	private String analysis;
	private String trap;
	private String level;
	private String duration;
	private String transferability;
	private String urlVignette;
	private String labelReferent1;
	private String labelReferent2;
	private String labelReferent3;
	private String title;
	private Date datePublication;
    private Date dateModification;
	private String lastContributor;
	private String id;
	private String author;
	private String owner;
	private Boolean draft;
	private Map<String,String> pj;
	private String viaeduc;
	private String dun;
	private Boolean experitheque;
	private String urlExpe;


//	/** Document comments. */
//    private List<CommentDTO> comments;
//
//	public ActiviteBean(){
//		this.comments = new ArrayList<CommentDTO>();
//	}

	public List<ReferentBean> getLstReferent1() {
		return lstReferent1;
	}
	public void setLstReferent1(List<ReferentBean> lstReferent1) {
		this.lstReferent1 = lstReferent1;
	}
	public List<ReferentBean> getLstReferent2() {
		return lstReferent2;
	}
	public void setLstReferent2(List<ReferentBean> lstReferent2) {
		this.lstReferent2 = lstReferent2;
	}
	public List<ReferentBean> getLstReferent3() {
		return lstReferent3;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public void setLstReferent3(List<ReferentBean> lstReferent3) {
		this.lstReferent3 = lstReferent3;
	}
	public String getLabelReferent1() {
		return labelReferent1;
	}
	public void setLabelReferent1(String labelReferent1) {
		this.labelReferent1 = labelReferent1;
	}
	public String getLabelReferent2() {
		return labelReferent2;
	}
	public void setLabelReferent2(String labelReferent2) {
		this.labelReferent2 = labelReferent2;
	}
	public String getLabelReferent3() {
		return labelReferent3;
	}
	public void setLabelReferent3(String labelReferent3) {
		this.labelReferent3 = labelReferent3;
	}
	public List<String> getLstDisciplines() {
		return lstDisciplines;
	}
	public void setLstDisciplines(List<String> lstDisciplines) {
		this.lstDisciplines = lstDisciplines;
	}
	public List<String> getLstPublics() {
		return lstPublics;
	}
	public void setLstPublics(List<String> lstPublics) {
		this.lstPublics = lstPublics;
	}
	public String getLevel() {
		return level;
	}
	public void setLevel(String level) {
		this.level = level;
	}
	public String getLastContributor() {
		return lastContributor;
	}
	public void setLastContributor(String lastContributor) {
		this.lastContributor = lastContributor;
	}
	public String getDuration() {
		return duration;
	}
	public void setDuration(String duration) {
		this.duration = duration;
	}
	public String getTransferability() {
		return transferability;
	}
	public void setTransferability(String transferability) {
		this.transferability = transferability;
	}
	public List<String> getLstPedagogicals() {
		return lstPedagogicals;
	}
	public void setLstPedagogicals(List<String> lstPedagogicals) {
		this.lstPedagogicals = lstPedagogicals;
	}
	public List<String> getLstPractices() {
		return lstPractices;
	}
	public void setLstPractices(List<String> lstPractices) {
		this.lstPractices = lstPractices;
	}
	public List<String> getLstCadres() {
		return lstCadres;
	}
	public void setLstCadres(List<String> lstCadres) {
		this.lstCadres = lstCadres;
	}
	public List<String> getLstPlaces() {
		return lstPlaces;
	}
	public void setLstPlaces(List<String> lstPlaces) {
		this.lstPlaces = lstPlaces;
	}
	public List<String> getLstTools() {
		return lstTools;
	}
	public void setLstTools(List<String> lstTools) {
		this.lstTools = lstTools;
	}
	public List<String> getLstSoftware() {
		return lstSoftware;
	}
	public void setLstSoftware(List<String> lstSoftware) {
		this.lstSoftware = lstSoftware;
	}
	public List<LinkBean> getLstESoftware() {
		return lstESoftware;
	}
	public void setLstESoftware(List<LinkBean> lstESoftware) {
		this.lstESoftware = lstESoftware;
	}
	public List<String> getLstCompetence() {
		return lstCompetence;
	}
	public void setLstCompetence(List<String> lstCompetence) {
		this.lstCompetence = lstCompetence;
	}
	public String getSummary() {
		return summary;
	}
	public void setSummary(String summary) {
		this.summary = summary;
	}
	public String getScenario() {
		return scenario;
	}
	public void setScenario(String scenario) {
		this.scenario = scenario;
	}
	public String getAnalysis() {
		return analysis;
	}
	public void setAnalysis(String analysis) {
		this.analysis = analysis;
	}
	public String getTrap() {
		return trap;
	}
	public void setTrap(String trap) {
		this.trap = trap;
	}
	public String getUrlVignette() {
		return urlVignette;
	}
	public void setUrlVignette(String urlVignette) {
		this.urlVignette = urlVignette;
	}
	public Date getDatePublication() {
		return datePublication;
	}
	public void setDatePublication(Date datePublication) {
		this.datePublication = datePublication;
	}
	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}
	public String getAuthor() {
		return author;
	}
	public void setAuthor(String author) {
		this.author = author;
	}
	public String getOwner() {
		return owner;
	}
	public void setOwner(String owner) {
		this.owner = owner;
	}
	public Boolean getDraft() {
		return draft;
	}
	public void setDraft(Boolean draft) {
		this.draft = draft;
	}
	public Map<String, String> getPj() {
		return pj;
	}
	public void setPj(Map<String, String> pj) {
		this.pj = pj;
	}
	public String getViaeduc() {
		return viaeduc;
	}
	public void setViaeduc(String viaeduc) {
		this.viaeduc = viaeduc;
	}
	public String getDun() {
		return dun;
	}
	public void setDun(String dun) {
		this.dun = dun;
	}
	public List<String> getLstParcours() {
		return lstParcours;
	}
	public void setLstParcours(List<String> lstParcours) {
		this.lstParcours = lstParcours;
	}
	public List<String> getLstAxes() {
		return lstAxes;
	}
	public void setLstAxes(List<String> lstAxes) {
		this.lstAxes = lstAxes;
	}
	public Boolean getExperitheque() {
		return experitheque;
	}
	public void setExperitheque(Boolean experitheque) {
		this.experitheque = experitheque;
	}
	public String getUrlExpe() {
		return urlExpe;
	}
	public void setUrlExpe(String urlExpe) {
		this.urlExpe = urlExpe;
	}

    /**
     * Getter for dateModification.
     * 
     * @return the dateModification
     */
    public Date getDateModification() {
        return dateModification;
    }

    /**
     * Setter for dateModification.
     * 
     * @param dateModification the dateModification to set
     */
    public void setDateModification(Date dateModification) {
        this.dateModification = dateModification;
    }

}

==> cartoun-detailactivite-1.2.0-sources.jar: fr/toutatice/cartoun/portlet/detailactivite/bean/ActiviteBean.java <==
package fr.toutatice.cartoun.portlet.detailactivite.bean;

import java.util.Date;
import java.util.List;
import java.util.Map;

public class ActiviteBean {

	private List<ReferentBean> lstReferent1;
	private List<ReferentBean> lstReferent2;
	private List<ReferentBean> lstReferent3;
	private List<LinkBean> lstESoftware;
	private List<String> lstDisciplines;
	private List<String> lstPublics;
	private List<String> lstPedagogicals;
	private List<String> lstPractices;
	private List<String> lstCadres;
	private List<String> lstPlaces;
	private List<String> lstTools;
	private List<String> lstSoftware;
	private List<String> lstCompetence;
	private List<String> lstParcours;
	private List<String> lstAxes;
	private String summary;
	private String scenario;
	private String analysis;
	private String trap;
	private String level;
	private String duration;
	private String transferability;
	private String urlVignette;
	private String labelReferent1;
	private String labelReferent2;
	private String labelReferent3;
	private String title;
	private Date datePublication;
    private Date dateModification;
	private String lastContributor;
	private String id;
	private String author;
	private Boolean draft;
	private Map<String,String> pj;
	private String viaeduc;
	private String dun;
	private Boolean experitheque;
	private String urlExpe;
    private String reperePrincipal;
    private String repereOther;
    private String webId;

    private boolean displayWarning;


//	/** Document comments. */
//    private List<CommentDTO> comments;
//
//	public ActiviteBean(){
//		this.comments = new ArrayList<CommentDTO>();
//	}

	public List<ReferentBean> getLstReferent1() {
		return lstReferent1;
	}
	public void setLstReferent1(List<ReferentBean> lstReferent1) {
		this.lstReferent1 = lstReferent1;
	}
	public List<ReferentBean> getLstReferent2() {
		return lstReferent2;
	}
	public void setLstReferent2(List<ReferentBean> lstReferent2) {
		this.lstReferent2 = lstReferent2;
	}
	public List<ReferentBean> getLstReferent3() {
		return lstReferent3;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public void setLstReferent3(List<ReferentBean> lstReferent3) {
		this.lstReferent3 = lstReferent3;
	}
	public String getLabelReferent1() {
		return labelReferent1;
	}
	public void setLabelReferent1(String labelReferent1) {
		this.labelReferent1 = labelReferent1;
	}
	public String getLabelReferent2() {
		return labelReferent2;
	}
	public void setLabelReferent2(String labelReferent2) {
		this.labelReferent2 = labelReferent2;
	}
	public String getLabelReferent3() {
		return labelReferent3;
	}
	public void setLabelReferent3(String labelReferent3) {
		this.labelReferent3 = labelReferent3;
	}
	public List<String> getLstDisciplines() {
		return lstDisciplines;
	}
	public void setLstDisciplines(List<String> lstDisciplines) {
		this.lstDisciplines = lstDisciplines;
	}
	public List<String> getLstPublics() {
		return lstPublics;
	}
	public void setLstPublics(List<String> lstPublics) {
		this.lstPublics = lstPublics;
	}
	public String getLevel() {
		return level;
	}
	public void setLevel(String level) {
		this.level = level;
	}
	public String getLastContributor() {
		return lastContributor;
	}
	public void setLastContributor(String lastContributor) {
		this.lastContributor = lastContributor;
	}
	public String getDuration() {
		return duration;
	}
	public void setDuration(String duration) {
		this.duration = duration;
	}
	public String getTransferability() {
		return transferability;
	}
	public void setTransferability(String transferability) {
		this.transferability = transferability;
	}
	public List<String> getLstPedagogicals() {
		return lstPedagogicals;
	}
	public void setLstPedagogicals(List<String> lstPedagogicals) {
		this.lstPedagogicals = lstPedagogicals;
	}
	public List<String> getLstPractices() {
		return lstPractices;
	}
	public void setLstPractices(List<String> lstPractices) {
		this.lstPractices = lstPractices;
	}
	public List<String> getLstCadres() {
		return lstCadres;
	}
	public void setLstCadres(List<String> lstCadres) {
		this.lstCadres = lstCadres;
	}
	public List<String> getLstPlaces() {
		return lstPlaces;
	}
	public void setLstPlaces(List<String> lstPlaces) {
		this.lstPlaces = lstPlaces;
	}
	public List<String> getLstTools() {
		return lstTools;
	}
	public void setLstTools(List<String> lstTools) {
		this.lstTools = lstTools;
	}
	public List<String> getLstSoftware() {
		return lstSoftware;
	}
	public void setLstSoftware(List<String> lstSoftware) {
		this.lstSoftware = lstSoftware;
	}
	public List<LinkBean> getLstESoftware() {
		return lstESoftware;
	}
	public void setLstESoftware(List<LinkBean> lstESoftware) {
		this.lstESoftware = lstESoftware;
	}
	public List<String> getLstCompetence() {
		return lstCompetence;
	}
	public void setLstCompetence(List<String> lstCompetence) {
		this.lstCompetence = lstCompetence;
	}
	public String getSummary() {
		return summary;
	}
	public void setSummary(String summary) {
		this.summary = summary;
	}
	public String getScenario() {
		return scenario;
	}
	public void setScenario(String scenario) {
		this.scenario = scenario;
	}
	public String getAnalysis() {
		return analysis;
	}
	public void setAnalysis(String analysis) {
		this.analysis = analysis;
	}
	public String getTrap() {
		return trap;
	}
	public void setTrap(String trap) {
		this.trap = trap;
	}
	public String getUrlVignette() {
		return urlVignette;
	}
	public void setUrlVignette(String urlVignette) {
		this.urlVignette = urlVignette;
	}
	public Date getDatePublication() {
		return datePublication;
	}
	public void setDatePublication(Date datePublication) {
		this.datePublication = datePublication;
	}
	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}
	public String getAuthor() {
		return author;
	}
	public void setAuthor(String author) {
		this.author = author;
	}
	public Boolean getDraft() {
		return draft;
	}
	public void setDraft(Boolean draft) {
		this.draft = draft;
	}
	public Map<String, String> getPj() {
		return pj;
	}
	public void setPj(Map<String, String> pj) {
		this.pj = pj;
	}
	public String getViaeduc() {
		return viaeduc;
	}
	public void setViaeduc(String viaeduc) {
		this.viaeduc = viaeduc;
	}
	public String getDun() {
		return dun;
	}
	public void setDun(String dun) {
		this.dun = dun;
	}
	public List<String> getLstParcours() {
		return lstParcours;
	}
	public void setLstParcours(List<String> lstParcours) {
		this.lstParcours = lstParcours;
	}
	public List<String> getLstAxes() {
		return lstAxes;
	}
	public void setLstAxes(List<String> lstAxes) {
		this.lstAxes = lstAxes;
	}
	public Boolean getExperitheque() {
		return experitheque;
	}
	public void setExperitheque(Boolean experitheque) {
		this.experitheque = experitheque;
	}
	public String getUrlExpe() {
		return urlExpe;
	}
	public void setUrlExpe(String urlExpe) {
		this.urlExpe = urlExpe;
	}

    /**
     * Getter for dateModification.
     *
     * @return the dateModification
     */
    public Date getDateModification() {
        return dateModification;
    }

    /**
     * Setter for dateModification.
     *
     * @param dateModification the dateModification to set
     */
    public void setDateModification(Date dateModification) {
        this.dateModification = dateModification;
    }
    /**
     * Getter for webId.
     * @return the webId
     */
    public String getWebId() {
        return webId;
    }
    /**
     * Setter for webId.
     * @param webId the webId to set
     */
    public void setWebId(String webId) {
        this.webId = webId;
    }

    /**
     * Getter for reperePrincipal.
     *
     * @return the reperePrincipal
     */
    public String getReperePrincipal() {
        return reperePrincipal;
    }

    /**
     * Setter for reperePrincipal.
     *
     * @param reperePrincipal the reperePrincipal to set
     */
    public void setReperePrincipal(String reperePrincipal) {
        this.reperePrincipal = reperePrincipal;
    }

    /**
     * Getter for repereOther.
     *
     * @return the repereOther
     */
    public String getRepereOther() {
        return repereOther;
    }

    /**
     * Setter for repereOther.
     *
     * @param repereOther the repereOther to set
     */
    public void setRepereOther(String repereOther) {
        this.repereOther = repereOther;
    }
    /**
     * Getter for displayWarning.
     * @return the displayWarning
     */
    public boolean isDisplayWarning() {
        return displayWarning;
    }
    /**
     * Setter for displayWarning.
     * @param displayWarning the displayWarning to set
     */
    public void setDisplayWarning(boolean displayWarning) {
        this.displayWarning = displayWarning;
    }

}
